@@ -1,20 +1,21 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::alloc::{GlobalAlloc, Layout, System};
 
 // TODO: double check that this is working correctly... and use the sanitizer to be sure
 #[global_allocator]
-static A: SodiumAllocator = SodiumAllocator;
+static A: ZeroingAllocator = ZeroingAllocator;
 
-struct SodiumAllocator;
+struct ZeroingAllocator;
 
-unsafe impl GlobalAlloc for SodiumAllocator {
+unsafe impl GlobalAlloc for ZeroingAllocator {
     unsafe fn alloc(&self, layout: Layout) -> *mut u8 {
         System.alloc(layout)
     }
 
     unsafe fn dealloc(&self, ptr: *mut u8, layout: Layout) {
-        libsodium_sys::sodium_memzero(ptr as _, layout.size());
+        // TODO perhaps use volatile_set_memory when stabilized
+        libc::explicit_bzero(ptr.cast(), layout.size());
         System.dealloc(ptr, layout);
     }
 }
