@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::path::Path;
 
@@ -19,7 +19,7 @@ pub fn init(database_path: &Path) -> Result<()> {
 
     // No entries to write when creating a new database
     let entries = Entries::new();
-    let database = entries::encrypt(&mut header, &entries, &key);
+    let database = entries::encrypt(&mut header, &entries, &key)?;
 
     database.write_new(database_path)
 }
