@@ -1,10 +1,10 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::io::Write;
 
-use sodiumoxide::crypto::pwhash::argon2id13;
 use termion::input::TermRead;
 
+use crate::crypto::argon2;
 use crate::header::Header;
 
 const NUM_WORDS: u32 = 6;
@@ -16,7 +16,7 @@ pub fn new_passphrase(header: &mut Header) -> String {
     println!("Remember this passphrase! It will not be displayed again.");
 
     // Every new passphrase gets a new salt
-    header.salt = argon2id13::gen_salt();
+    header.salt = argon2::gen_salt();
 
     passphrase
 }
