@@ -1,8 +1,7 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
-use std::convert::TryInto;
-
-use sodiumoxide::randombytes;
+use rand::rngs::OsRng;
+use rand::seq::SliceRandom;
 
 #[derive(Clone, Copy, Debug)]
 pub enum CharSet {
@@ -76,7 +75,7 @@ pub const GRAPH: &str = concat!(
 );
 
 impl CharSet {
-    fn chars(&self) -> &str {
+    fn chars(self) -> Vec<char> {
         match self {
             CharSet::Digit => DIGIT,
             CharSet::Lower => LOWER,
@@ -85,21 +84,15 @@ impl CharSet {
             CharSet::Alpha => ALPHA,
             CharSet::Alnum => ALNUM,
             CharSet::Graph => GRAPH,
-        }
+        }.chars().collect()
     }
 }
 
 pub fn random_string(charset: CharSet, length: u32) -> String {
     let chars = charset.chars();
-    let mut password = String::with_capacity(length.try_into().unwrap());
-    for _ in 0..length {
-        let index: usize = randombytes::randombytes_uniform(chars.len().try_into().unwrap())
-            .try_into()
-            .unwrap();
-        password.push(chars.chars().nth(index).unwrap());
-    }
-
-    password
+    (0..length)
+        .map(|_| chars.choose(&mut OsRng).unwrap())
+        .collect::<String>()
 }
 
 #[cfg(test)]
@@ -116,6 +109,6 @@ mod tests {
     fn random_string_characters_are_taken_from_charset() {
         let charset = CharSet::Graph;
         let string = random_string(charset, 20);
-        assert!(string.chars().all(|c| charset.chars().contains(c)))
+        assert!(string.chars().all(|c| charset.chars().contains(&c)))
     }
 }
