@@ -1,10 +1,10 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use std::path::Path;
 
 use anyhow::Result;
-use sodiumoxide::crypto::aead::xchacha20poly1305_ietf::Key;
 
+use crate::crypto::chacha20::Key;
 use crate::entries::Entries;
 use crate::repl::util;
 
